@@ -1,3 +1,4 @@
+//
 //   ________.__          __  .__  __
 //  /  _____/|__| _______/  |_|__|/  |_
 // /   \  ___|  |/  ___/\   __\  \   __\
@@ -5,15 +6,7 @@
 //  \______  /__/____  > |__| |__||__|
 //         \/        \/
 //
-// ------------------ Style police begin ------------------
 #![warn(clippy::all, clippy::pedantic, clippy::nursery, clippy::cargo)]
-// This would decrease readability
-#![allow(clippy::module_name_repetitions)]
-// Not my fault
-#![allow(clippy::multiple_crate_versions)]
-// Boring
-#![allow(clippy::missing_panics_doc)]
-// Test env should be chill
 #![cfg_attr(
     test,
     allow(
@@ -26,14 +19,15 @@
         clippy::missing_docs_in_private_items,
     )
 )]
-// ------------------ Style police end ------------------
 
-pub mod encrypt;
-pub mod errors;
-pub mod file;
-
-#[cfg(feature = "clipboard")]
 pub mod clipboard;
+pub mod error;
+pub mod file;
+pub mod github;
+pub mod hash;
+pub mod patch;
+pub mod project;
+pub mod server;
 
-pub use errors::Error;
+pub use error::Error;
 pub type Result<T> = std::result::Result<T, Error>;
